var localStore = function(directory)
{
  this.init(directory);
}

localStore.prototype = {
  localDirFh : null,

  init : function(directory)
  {
    var localStoreDir = null;
    var fileUrl = null;

    var discussPref = Components.classes["@mozilla.org/preferences-service;1"]
                                .getService(Components.interfaces.nsIPrefService)
                                .getBranch(null);
    if (!directory) {
      try {
        localStoreDir = discussPref.getCharPref("localstore.directory");
      } catch (ex) {
        localStoreDir = "";
        alert ("Please set the default folder for saving local posts");
      }
    } else localStoreDir = directory;

    try { // can't get handle of nsIFileURL post mozilla 1.2b for some reason
       fileUrl = Components.classes["@mozilla.org/network/standard-url;1"]
                              .createInstance(Components.interfaces.nsIFileURL);
       fileUrl.spec = localStoreDir;
       this.localDirFh = fileUrl.file;
    } catch (e) {
       var gIOService   = Components.classes["@mozilla.org/network/io-service;1"]
                                    .getService(Components.interfaces.nsIIOService);
       var gFileHandler = gIOService.getProtocolHandler("file")
                                    .QueryInterface(Components.interfaces.nsIFileProtocolHandler);
       this.localDirFh = gFileHandler.getFileFromURLSpec(localStoreDir);
    }

    if (!this.localDirFh.exists()) {
      if (this.localDirFh.isWritable()) {
        this.localDirFh.create(1, 0644);
      } else {
        alert ("Directory does not exist and could not be created");
      }
    }
  },

  saveFile : function(filename, content)
  {
    var fileHandle = this.localDirFh.clone();
    fileHandle.append(filename);
    var fileOut = Components.classes["@mozilla.org/network/file-output-stream;1"].createInstance();
    var outStream = fileOut.QueryInterface(Components.interfaces.nsIFileOutputStream);

    // flag from nsIFile.idl
    var NORMAL_FILE_TYPE = 0;
    // flags from prio.h [ http://lxr.mozilla.org/seamonkey/source/nsprpub/pr/include/prio.h ]
    var PR_WRONLY        = 0x02;
    var PR_TRUNCATE      = 0x20;
    var OWNER_WRITE      = 0664;
    if (!fileHandle.exists()) {
      fileHandle.create(NORMAL_FILE_TYPE, 0644);
    }
    if (fileHandle.isWritable()) {
      outStream.init(fileHandle, PR_WRONLY | PR_TRUNCATE, OWNER_WRITE, 0);
      outStream.write(content, content.length);
      outStream.close();
    } else {
      alert ("error writing file: " + fileHandle.path);
    }
  },

  deleteFile : function(filename)
  {
    var fileHandle = this.localDirFh.clone();
    fileHandle.append(filename);
    if (fileHandle.exists())
    {
      if (fileHandle.isWritable()) {
        fileHandle.remove(false);
      } else {
        alert("Permission denied trying to delete file");
      }
    }
  },

  getFileContent : function(filename)
  {
    var result;
    var fileHandle = this.localDirFh.clone();
    fileHandle.append(filename);
    var fileOut    = Components.classes["@mozilla.org/network/file-input-stream;1"].createInstance();
    var inStream   = fileOut.QueryInterface(Components.interfaces.nsIFileInputStream);
    var READ_ONLY  = 0x01;
    var OWNER_READ = 0444;
    if (fileHandle.exists())
    {
      inStream.init(fileHandle, READ_ONLY, OWNER_READ, 0);
      var scriptableInputStream = Components.classes["@mozilla.org/scriptableinputstream;1"]
                                    .createInstance(Components.interfaces.nsIScriptableInputStream);
      scriptableInputStream.init(inStream);
      var fileSize = scriptableInputStream.available();
      result = scriptableInputStream.read(fileSize);
      scriptableInputStream.close();
      inStream.close();
    }
    return result;
  }
}